| MissComb | R Documentation |
R6 Class for missing combinations The class has the field for the combinations and custom plot function
R6 Class for missing combinations The class has the field for the combinations and custom plot function
na_combinationsdataframe with missing combinations
new()Creates a new MissComb Object
MissComb$new(na_comb = NA)
na_combdataframe with missing combinations
plot()custom plot function for the Class
MissComb$plot( labels = "index", label_length = 30, show_numbers = TRUE, text_offset = 50, top_n = 10, bar_color = "#FC8D62", plot_title = "NA combinations", x_lab = "combination", y_lab = "n" )
labelswhich labels should be used. options: be 'index' or 'name'. 'index' results in a much shorter length usually
label_lengthafter how many characters the line should be splitted
show_numbersif 'TRUE' shows the numbers of observations next to the bar.
text_offsetdefines the offset of the text to the bar
top_nshow the 'top_n' cases
bar_colordefines the color of the bars
plot_titletitle of the plot
x_labx axis label
y_laby axis label
clone()The objects of this class are cloneable with this method.
MissComb$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.