| ReportContent | R Documentation |
R6 Class for missing combinations The class has the field for the combinations and custom plot function
R6 Class for missing combinations The class has the field for the combinations and custom plot function
idid of object
typeof content currently: text, ggplot, cor_matrix
contentcontent
new()Creates a new ReportContent Object
ReportContent$new(id = NULL, type = NULL, content = NULL)
idid of object
typetype of content. currently: text, ggplot, cor_matrix, dataframe
contentcontent
print_report()prints the object for the different types
ReportContent$print_report()
clone()The objects of this class are cloneable with this method.
ReportContent$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.