| ReportPlot | R Documentation |
R6 Class for missing combinations The class has the field for the combinations and custom plot function
R6 Class for missing combinations The class has the field for the combinations and custom plot function
titledataframe with missing combinations
descr_keydataframe with missing combinations
plotdataframe with missing combinations
new()Creates a new ReportPlot Object
ReportPlot$new(title = NULL, descr_key = NULL, descr_dict = NULL, plot = NULL)
titletitle of the plot
descr_keydescription of the plot
descr_dictdict with description strings
plotplot to display
get_description()generates the description for the plot
ReportPlot$get_description()
descr_keykey of the description in the dict
descr_dictdict of description
clone()The objects of this class are cloneable with this method.
ReportPlot$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.